# 🚀 awesome bash cli (abcli)

🚀 `abcli` is an implementation of [🔻 giza](https://github.com/kamangir/giza) and the library behind [these projects](https://github.com/kamangir/kamangir).

![image](https://github.com/kamangir/assets/blob/main/abcli/marquee.png?raw=true)

# installation

[![PyPI version](https://img.shields.io/pypi/v/abcli.svg)](https://pypi.org/project/abcli/)

To install `abcli`, type in,

```bash
pip install abcli
```

or follow these (outdated) instructions for custom environments:

- [Amazon EC2 instances](https://github.com/kamangir/awesome-bash-cli/wiki/ec2)
- [Amazon SageMaker](https://github.com/kamangir/notebooks-and-scripts/blob/main/SageMaker.md)
- [Jetson Nano](https://github.com/kamangir/awesome-bash-cli/wiki/Jetson-Nano)
- [macOS](https://github.com/kamangir/awesome-bash-cli/wiki/macOS)
- [Raspberry Pi](https://github.com/kamangir/awesome-bash-cli/wiki/Raspberry-Pi)

To see the list of `abcli` commands type in:

```
abcli ?
```

# configuration

create a copy of [`sample.env`](./sample.env) as `.env` and fill in the secrets.

# branches

- [current](.) active and default branch.
- [main](https://github.com/kamangir/awesome-bash-cli/tree/main) legacy branch, is running on [a cluster of Raspberry pis](https://github.com/kamangir/blue-bracket). ⚠️ do not touch. ⚠️
